@@ -2,9 +2,9 @@
  * @Author: BuddyCoder
  * @Date: 2021-08-24 14:50:48
  * @LastEditors: BuddyCoder
- * @LastEditTime: 2022-03-29 11:23:42
+ * @LastEditTime: 2022-03-29 17:29:56
  * @Description: 
- * @FilePath: /pgmacro/src/macros/crud_table_impl.rs
+ * @FilePath: /pgmacro_expand_demo/pgmacro/src/macros/crud_table_impl.rs
  * MIT
  */
   //use proc_macro2::Ident;
@@ -127,12 +127,16 @@
  fn py_get_name(table_name: &str) -> proc_macro2::TokenStream {
      quote! {
          fn get_table_name(prefix: &str,suffix:&str) -> String {
-             if prefix == "" {
+            let temp_table_name = if prefix == "" {
                  format!("{}",#table_name)
              }else{
                  format!("{}_{}",prefix,#table_name)
              }
-            
+            if suffix == "" {
+                format!("{}",temp_table_name)
+            }else{
+                format!("{}_{}",temp_table_name,suffix)
+            }   
          }
      }
  }
@@ -179,7 +183,7 @@
      let py_insert_quoted = fields.iter().map(|f| f.py_insert_column());
      let py_insert = quote! {
          fn save(&self,prefix:&str) -> Result<(String, Vec<&(dyn ToSql + Sync)>), String> {
-             let table_name = Self::get_table_name(prefix);
+             let table_name = Self::get_table_name(prefix,"");
              let mut sql_columns: Vec<&str> = Vec::new();
              let mut sql_agrs: Vec<String> = Vec::new();
              let mut agrs: Vec<&(dyn ToSql + Sync)> = Vec::new();
